<?php
add_action( 'after_setup_theme', 'picoclean_setup' );

if ( ! function_exists( 'picoclean_setup' ) ):

/**
 * Sets up theme defaults and registers support for various WordPress features.
*/
function picoclean_setup() {

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// Make theme available for translation
	// Translations can be filed in the /languages/ directory
	load_theme_textdomain( 'picoclean', TEMPLATEPATH . '/languages' );

	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'picoclean' ),
	) );

	// This theme allows users to set a custom background
	add_custom_background();

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 940 pixels wide by 198 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( '150', '150', true );

	//Sidebars
	register_sidebar(array(
		'name' => __('Sidebar', 'picoclean'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
	));
}
endif;

//Content width
if (!isset($content_width)) {
	$content_width = 630;
}

?>
